SortedSetFetchRequest___ByScore class

Inheritance
  • Object
  • GeneratedMessage
  • SortedSetFetchRequest___ByScore

Constructors

SortedSetFetchRequest___ByScore({Unbounded_? unboundedMin, SortedSetFetchRequest___ByScore__Score? minScore, Unbounded_? unboundedMax, SortedSetFetchRequest___ByScore__Score? maxScore, int? offset, int? count})
factory
SortedSetFetchRequest___ByScore.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
SortedSetFetchRequest___ByScore.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

count ↔ int
getter/setter pair
eventPlugin → EventPlugin?
Subclasses can override this getter to be notified of changes to protobuf fields.
no setterinherited
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setteroverride
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
maxScore ↔ SortedSetFetchRequest___ByScore__Score
getter/setter pair
minScore ↔ SortedSetFetchRequest___ByScore__Score
getter/setter pair
offset ↔ int
Offset and count are used to only get a range of the matching elements, similar to "SELECT LIMIT offset, count" in SQL. A negative count returns all elements from the offset. Use (0, -1) to return all matching elements.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unboundedMax ↔ Unbounded_
getter/setter pair
unboundedMin ↔ Unbounded_
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearCount() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearMax() → void
clearMaxScore() → void
clearMin() → void
clearMinScore() → void
clearOffset() → void
clearUnboundedMax() → void
clearUnboundedMin() → void
clone() → SortedSetFetchRequest___ByScore
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
override
copyWith(void updates(SortedSetFetchRequest___ByScore)) → SortedSetFetchRequest___ByScore
Apply updates to a copy of this message.
override
createEmptyInstance() → SortedSetFetchRequest___ByScore
Creates an empty instance of the same message type as this.
override
createMapField<K, V>(int tagNumber, MapFieldInfo<K, V> fi) → Map<K, V>
Creates a Map representing a map field.
inherited
createRepeatedField<T>(int tagNumber, FieldInfo<T> fi) → List<T>
Creates List implementing a mutable repeated field.
inherited
ensureMaxScore() → SortedSetFetchRequest___ByScore__Score
ensureMinScore() → SortedSetFetchRequest___ByScore__Score
ensureUnboundedMax() → Unbounded_
ensureUnboundedMin() → Unbounded_
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasCount() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasMaxScore() → bool
hasMinScore() → bool
hasOffset() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasUnboundedMax() → bool
hasUnboundedMin() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichMax() → SortedSetFetchRequest___ByScore_Max
whichMin() → SortedSetFetchRequest___ByScore_Min
writeToBuffer() → Uint8List
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited