LeaderboardServiceBase class abstract

Annotations
  • @GrpcServiceName.new('leaderboard.Leaderboard')

Constructors

LeaderboardServiceBase()

Properties

$name → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
deleteLeaderboard(ServiceCall call, DeleteLeaderboardRequest_ request) → Future<Empty_>
deleteLeaderboard_Pre(ServiceCall call, Future<DeleteLeaderboardRequest_> request) → Future<Empty_>
getByRank(ServiceCall call, GetByRankRequest_ request) → Future<GetByRankResponse_>
getByRank_Pre(ServiceCall call, Future<GetByRankRequest_> request) → Future<GetByRankResponse_>
getByScore(ServiceCall call, GetByScoreRequest_ request) → Future<GetByScoreResponse_>
getByScore_Pre(ServiceCall call, Future<GetByScoreRequest_> request) → Future<GetByScoreResponse_>
getLeaderboardLength(ServiceCall call, GetLeaderboardLengthRequest_ request) → Future<GetLeaderboardLengthResponse_>
getLeaderboardLength_Pre(ServiceCall call, Future<GetLeaderboardLengthRequest_> request) → Future<GetLeaderboardLengthResponse_>
getRank(ServiceCall call, GetRankRequest_ request) → Future<GetRankResponse_>
getRank_Pre(ServiceCall call, Future<GetRankRequest_> request) → Future<GetRankResponse_>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeElements(ServiceCall call, RemoveElementsRequest_ request) → Future<Empty_>
removeElements_Pre(ServiceCall call, Future<RemoveElementsRequest_> request) → Future<Empty_>
toString() → String
A string representation of this object.
inherited
upsertElements(ServiceCall call, UpsertElementsRequest_ request) → Future<Empty_>
upsertElements_Pre(ServiceCall call, Future<UpsertElementsRequest_> request) → Future<Empty_>

Operators

operator ==(Object other) → bool
The equality operator.
inherited