VectorIndexServiceBase class abstract

Annotations
  • @GrpcServiceName.new('vectorindex.VectorIndex')

Constructors

VectorIndexServiceBase()

Properties

$name → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
deleteItemBatch(ServiceCall call, DeleteItemBatchRequest_ request) → Future<DeleteItemBatchResponse_>
deleteItemBatch_Pre(ServiceCall call, Future<DeleteItemBatchRequest_> request) → Future<DeleteItemBatchResponse_>
getItemBatch(ServiceCall call, GetItemBatchRequest_ request) → Future<GetItemBatchResponse_>
getItemBatch_Pre(ServiceCall call, Future<GetItemBatchRequest_> request) → Future<GetItemBatchResponse_>
getItemMetadataBatch(ServiceCall call, GetItemMetadataBatchRequest_ request) → Future<GetItemMetadataBatchResponse_>
getItemMetadataBatch_Pre(ServiceCall call, Future<GetItemMetadataBatchRequest_> request) → Future<GetItemMetadataBatchResponse_>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
search_Pre(ServiceCall call, Future<SearchRequest_> request) → Future<SearchResponse_>
searchAndFetchVectors(ServiceCall call, SearchAndFetchVectorsRequest_ request) → Future<SearchAndFetchVectorsResponse_>
searchAndFetchVectors_Pre(ServiceCall call, Future<SearchAndFetchVectorsRequest_> request) → Future<SearchAndFetchVectorsResponse_>
toString() → String
A string representation of this object.
inherited
upsertItemBatch(ServiceCall call, UpsertItemBatchRequest_ request) → Future<UpsertItemBatchResponse_>
upsertItemBatch_Pre(ServiceCall call, Future<UpsertItemBatchRequest_> request) → Future<UpsertItemBatchResponse_>

Operators

operator ==(Object other) → bool
The equality operator.
inherited