EnvMomentoV2TokenProvider class
Reads and parses a v2 API key and Momento service endpoint stored as environment variables MOMENTO_API_KEY and MOMENTO_ENDPOINT. Optionally provide alternate environment variable names.
- Implemented types
Constructors
- EnvMomentoV2TokenProvider({String apiKeyEnvVar = "MOMENTO_API_KEY", String endpointEnvVar = "MOMENTO_ENDPOINT"})
- Creates a CredentialProvider from the v2 API key and endpoint stored in the environment variables MOMENTO_API_KEY and MOMENTO_ENDPOINT. Optionally provide alternate environment variable names.
Properties
- apiKey → String
-
The API key used to construct the CredentialProvider
no setteroverride
- cacheEndpoint → String
-
The URI for the data plane endpoint
no setteroverride
- controlEndpoint → String
-
The URI for the control plane endpoint
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited